@@ -6,7 +6,7 @@ use Data::Dumper;
 use XML::RPC;
 use Carp qw(croak);
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub new {
     my ( $classe, $ref_args ) = @_;
@@ -44,6 +44,17 @@ sub listAllDomain {
     $self->_parseOutput($self->{XMLRPC}->xml_in());
 }
 
+sub getDestinationAddress {
+    my ( $self, $domain ) = @_;
+
+        $self->{XMLRPC}->call('config.get', { 
+                                type => 'domain',
+                                path => "$domain",
+				variable => 'mta_relay_advanced_host'});
+    
+    $self->_parseOutput($self->{XMLRPC}->xml_in());
+}
+
 sub createDomain {
     my ( $self, $domain, $destination ) = @_;
 
@@ -203,6 +214,12 @@ Method to list all domain.
 
 It return a scalar with XMLRPC answer (formatted or not).
 
+=item getDestinationAddress( $domain )
+
+Method to get the destination host for $domain.
+
+It return a scalar with XMLRPC answer (formatted or not).
+
 =item createDomain( $domain, $destination )
 
 Method to create domain $domain with destination $destination.
